A parser for mustache templates.
A parser for mustache templates.
(render template)(render template data)(render template data partials)Renders the template with the data and, if supplied, partials.
Renders the template with the data and, if supplied, partials.
(render-resource path)(render-resource path data)(render-resource path data partials)Renders a resource located on the classpath
Renders a resource located on the classpath
(replace-variables template data partials)Replaces variables in the template with their values from the data.
Replaces variables in the template with their values from the data.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |